==> nextcloud-20.0.12.tgz: nextcloud/apps/firstrunwizard/l10n/et_EE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "First run wizard" : "Esmase Käivituse Juhandaja",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt ja täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisa oma profiili infot! Lisa täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt, et sind oleks lihtsam ära tunda.",
    "About" : "Info",
    "Get the apps to sync your files" : "Hangi rakendusi failide sünkroniseerimiseks",
    "Desktop client" : "Töölaua klient",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Connect your desktop apps to %s" : "Ühenda oma töölaua rakendus %s",
    "Connect your calendar" : "Ühenda oma kalender",
    "Connect your contacts" : "Ühenda oma kontaktid",
    "Access files via WebDAV" : "Ligipääs WebDAV vahendusel",
    "A safe home for all your data" : "Turvaline koht sinu andmetele",
    "Server address" : "Serveri aadress",
    "Copy link" : "Kopeeri link"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/firstrunwizard/l10n/et_EE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "First run wizard" : "Esmase Käivituse Juhandaja",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt ja täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisa oma profiili infot! Lisa täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt, et sind oleks lihtsam ära tunda.",
    "About" : "Info",
    "Get the apps to sync your files" : "Hangi rakendusi failide sünkroniseerimiseks",
    "Desktop client" : "Töölaua klient",
    "iOS app" : "iOS-i rakendus",
    "Connect your desktop apps to %s" : "Ühenda oma töölaua rakendus %s",
    "Connect your calendar" : "Ühenda oma kalender",
    "Connect your contacts" : "Ühenda oma kontaktid",
    "Access files via WebDAV" : "Ligipääs WebDAV vahendusel",
    "A safe home for all your data" : "Turvaline koht sinu andmetele",
    "Server address" : "Serveri aadress",
    "Copy link" : "Kopeeri link",
    "Android app" : "Androidi rakendus"
},
"nplurals=2; plural=(n != 1);");
